"""
Tools for the Solana Agent system.

This package contains the base AutoTool class and built-in tool implementations.
"""

from solana_agent.plugins.tools.auto_tool import *

# Version of the domain model
__version__ = '14.0.0'
